Autoconfiguration
-----------------

Sometimes, you may find yourself in a position that you do not or you can't answer the question which asks you if you would like to install the default configuration file.

For that reason, if you set :code:`PYFUNCEBLE_AUTO_CONFIGURATION` as an environment variable with what you want an assignment, we do not ask that question. We simply do what we have to do without asking anything.

